# pydsstools

[![Documentation Status](https://readthedocs.org/projects/pydsstools/badge/?version=latest)](https://pydsstools.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/pydsstools.svg)](https://badge.fury.io/py/pydsstools)

A Cython-based Python library for reading and writing [HEC-DSS](http://www.hec.usace.army.mil/software/hec-dssvue/) database files.

## Features

- Regular and irregular time-series
- Paired data series
- Spatial grid records (HRAP, Albers/SHG, Specified, Undefined)
- Compatible with 64-bit Python on Windows and Linux

## Related Projects

- [dssvue](https://github.com/gyanz/dssvue) — GUI for HEC-DSS
- [hecdss-rs](https://github.com/gyanz/hecdss-rs) — Rust bindings for HEC-DSS

## Changes

See the [changelog](https://github.com/gyanz/pydsstools/blob/master/CHANGES.MD).

## Documentation

Read the full documentation at [pydsstools.readthedocs.io](https://pydsstools.readthedocs.io/).

## Installation

See the [installation guide](docs/source/installation.md).

## Contributing

All contributions, bug reports, bug fixes, documentation improvements, enhancements, and ideas are welcome.
Feel free to ask questions via [email](mailto:gyanBasyalz@gmail.com).

## License

This program is free software: you can modify and/or redistribute it under the [MIT](LICENSE) license.
